<?php 
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Plugin;
use Elementor\Repeater;
use Elementor\Icons_Manager;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow as Group_Control_Box_Shadow;
use Elementor\Modules\DynamicTags\Module as TagsModule;


class themesflat_options_elementor {
	public function __construct(){	
        add_action('elementor/documents/register_controls', [$this, 'themesflat_elementor_register_options'], 10);
        add_action('elementor/editor/before_enqueue_scripts', function() { wp_enqueue_script( 'elementor-preview-load', THEMESFLAT_LINK . 'js/elementor/elementor-preview-load.js', array( 'jquery' ), null, true );
        }, 10, 3);
    }

    public function themesflat_elementor_register_options($element){
        $post_id = $element->get_id();
        $post_type = get_post_type($post_id);

        if ( ($post_type !== 'post') && ($post_type !== 'portfolios') && ($post_type !== 'team') ) {
        	$this->themesflat_options_page_header($element);
            $this->themesflat_options_page_footer($element);                      
        }

        $this->themesflat_options_page($element);
        $this->themesflat_options_page_pagetitle($element);

        if ( $post_type == 'team' ) {
            $this->themesflat_options_team($element);
        }

        if ( $post_type == 'portfolios' ) {
            $this->themesflat_options_portfolio($element);
        }

        if ( $post_type == 'services' ) {
            $this->themesflat_options_services($element);
        }

    }

    public function themesflat_options_page_header($element) {
        // TF Header
        $element->start_controls_section(
            'themesflat_header_options',
            [
                'label' => esc_html__('TF Header', 'labaid'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );
        $element->add_control(
            'style_header',
            [
                'label'     => esc_html__( 'Header Style', 'labaid'),
                'type'      => Controls_Manager::SELECT,
                'default'   => '',
                'options'   => [
                	'' => esc_html__( 'Theme Setting', 'labaid'),
                    'header-default' => esc_html__( 'Header Default', 'labaid'),
                    'header-01' => esc_html__( 'Header 01', 'labaid' ),
                ],
            ]
        );
        $element->add_control(
            'h_options_topbar',
            [
                'label' => esc_html__( 'Topbar', 'labaid' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $element->add_control(
            'topbar_show',
            [
                'label'     => esc_html__( 'Top Bar', 'labaid'),
                'type'      => Controls_Manager::SELECT,
                'default'   => '',
                'options'   => [
                    '' => esc_html__( 'Theme Setting', 'labaid'),
                    0       => esc_html__( 'Hide', 'labaid'),
                    1       => esc_html__( 'Show', 'labaid'),                    
                ],
            ]
        ); 


        $element->add_responsive_control(
            'topbar_padding',
            [
                'label' => esc_html__( 'Padding', 'labaid' ),
                'type' => Controls_Manager::DIMENSIONS,
                'allowed_dimensions' => ['top','bottom'],
                'size_units' => [ 'px' ],
                'selectors' => [
                    '{{WRAPPER}} .themesflat-top .container-inside' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $element->add_control(
            'topbar_background_color',
            [
                'label' => esc_html__( 'Background', 'labaid' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .themesflat-top' => 'background: {{VALUE}};',                  
                ],
            ]
        );
        $element->add_control(
            'topbar_textcolor',
            [
                'label' => esc_html__( 'Color', 'labaid' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .themesflat-top .content-left ul li' => 'color: {{VALUE}};',                  
                ],
            ]
        );
        $element->add_control(
            'topbar_link_color',
            [
                'label' => esc_html__( 'Link Color', 'labaid' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .themesflat-top a' => 'color: {{VALUE}};',                  
                ],
            ]
        );
        $element->add_control(
            'topbar_link_color_hover',
            [
                'label' => esc_html__( 'Link Hover Color', 'labaid' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .themesflat-top a:hover' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .themesflat-top .wrap-btn-topbar .btn-topbar:before' => 'background-color: {{VALUE}};',
                ],
            ]
        );
        $element->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'topbar_typography',
                'label' => esc_html__( 'Typography', 'labaid' ),
                'selector' => '{{WRAPPER}} .themesflat-top',
            ]
        );

        
        $element->add_control(
            'topbar_email',
            [
                'label' => esc_html__( 'Infor Email Text', 'labaid' ),
                'type'    => Controls_Manager::TEXT,
                'default' => esc_html__( 'labaid@gmail.com', 'labaid' ),
                'placeholder' => esc_html__( 'labaid@gmail.com', 'labaid' ),
                'label_block' => true,
                'condition' => [ 'style_header' => 'header-02' ],
            ]
        );

        $element->add_control(
            'topbar_address',
            [
                'label' => esc_html__( 'Infor Address Text', 'labaid' ),
                'type'    => Controls_Manager::TEXT,
                'default' => esc_html__( 'CRGJ+6VP London, UK', 'labaid' ),
                'placeholder' => esc_html__( 'CRGJ+6VP London, UK', 'labaid' ),
                'label_block' => true,
                'condition' => [ 'style_header' => 'header-02' ],
            ]
        );

        $element->add_control(
            'h_options_header',
            [
                'label' => esc_html__( 'Header', 'labaid' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        // Logo
        $element->add_control(
            'site_logo',
            [
                'label'   => esc_html__( 'Custom Logo', 'labaid' ),
                'type'    => Controls_Manager::MEDIA,
            ]
        );
        $element->add_responsive_control(
            'logo_width',
            [
                'label'      => esc_html__( 'Logo Width', 'labaid' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range'      => [
                    'px' => [
                        'min' => 30,
                        'max' => 500,
                    ],
                    '%' => [
                        'min' => 50,
                        'max' => 150,
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} #header #logo a img, {{WRAPPER}} .modal-menu__panel-footer .logo-panel a img' => 'max-width: {{SIZE}}{{UNIT}} !important;',
                ],
            ]
        );

        $element->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'logo_bg_color',
                'label' => esc_html__( 'Logo Background Color', 'labaid' ),
                'types' => ['gradient' ],
                'selector' => '{{WRAPPER}}  #header .logo,{{WRAPPER}}  #header .logo::after',
            ]
        );


        $element->add_control(
            'header_absolute',
            [
                'label'     => esc_html__( 'Header Absolute', 'labaid'),
                'type'      => Controls_Manager::SELECT,
                'default'   => '',
                'options'   => [
                    '' => esc_html__( 'Theme Setting', 'labaid'),
                    0       => esc_html__( 'No', 'labaid'),
                    1       => esc_html__( 'Yes', 'labaid'),                    
                ],
                'condition' => [ 'style_header!' => '' ],
            ]
        );
        $element->add_control(
            'header_sticky',
            [
                'label'     => esc_html__( 'Header Sticky', 'labaid'),
                'type'      => Controls_Manager::SELECT,
                'default'   => '',
                'options'   => [
                    '' => esc_html__( 'Theme Setting', 'labaid'),
                    0       => esc_html__( 'No', 'labaid'),
                    1       => esc_html__( 'Yes', 'labaid'),                    
                ],
                'condition' => [ 'style_header!' => '' ],
            ]
        );
        $element->add_control(
            'header_search_box',
            [
                'label'     => esc_html__( 'Search Box', 'labaid'),
                'type'      => Controls_Manager::SELECT,
                'default'   => '',
                'options'   => [
                    '' => esc_html__( 'Theme Setting', 'labaid'),
                    0       => esc_html__( 'Hide', 'labaid'),
                    1       => esc_html__( 'Show', 'labaid'),                    
                ],
                'condition' => [ 'style_header!' => '' ],
            ]
        );        
        $element->add_control(
            'header_cart_icon',
            [
                'label'     => esc_html__( 'Header Cart', 'labaid'),
                'type'      => Controls_Manager::SELECT,
                'default'   => '',
                'options'   => [
                    '' => esc_html__( 'Theme Setting', 'labaid'),
                    0       => esc_html__( 'Hide', 'labaid'),
                    1       => esc_html__( 'Show', 'labaid'),                    
                ],
                'condition' => [ 'style_header!' => '' ],
            ]
        );

        $element->add_control(
            'header_sidebar_toggler',
            [
                'label'     => esc_html__( 'Sidebar Toggler', 'labaid'),
                'type'      => Controls_Manager::SELECT,
                'default'   => '',
                'options'   => [
                    '' => esc_html__( 'Theme Setting', 'labaid'),
                    0       => esc_html__( 'Hide', 'labaid'),
                    1       => esc_html__( 'Show', 'labaid'),                    
                ],
                'condition' => [ 'style_header!' => '' ],
            ]
        );
        $element->add_control(
            'header_backgroundcolor',
            [
                'label' => esc_html__( 'Header Background', 'labaid' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} #header.header-default' => 'background: {{VALUE}};',
                    '{{WRAPPER}} #header.header-default.header-01 .inner-header' => 'background: {{VALUE}};',
                ],
                'condition' => [ 'style_header!' => '' ],
            ]
        );
        $element->add_control(
            'header_height',
            [
                'label' => esc_html__( 'Header Height', 'labaid' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => 50,
                        'max' => 200,
                        'step' => 1,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} #mainnav > ul > li > a, {{WRAPPER}} #header .show-search, {{WRAPPER}} header .block a, {{WRAPPER}} #header .mini-cart-header .cart-count, {{WRAPPER}} #header .mini-cart .cart-count, {{WRAPPER}} .button-menu' => 'line-height: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} #header .header-wrap' => 'height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $element->add_control(
            'h_options_menu_header',
            [
                'label' => esc_html__( 'Menu Top Header', 'labaid' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $element->add_control(
            'top_header_link_color',
            [
                'label' => esc_html__( 'Color', 'labaid' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .header .inner-header ul li a' => 'color: {{VALUE}};',                  
                ],
            ]
        );
        $element->add_control(
            'top_header_link_color_hover',
            [
                'label' => esc_html__( 'Color Hover', 'labaid' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .header .inner-header ul li a:hover' => 'color: {{VALUE}};',                  
                ],
            ]
        );
        $element->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'top_header_link_typography',
                'label' => esc_html__( 'Typography', 'labaid' ),
                'selector' => '{{WRAPPER}} .header .inner-header ul li a',
            ]
        );

        $element->add_control(
            'h_options_button_header',
            [
                'label' => esc_html__( 'Button Header', 'labaid' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $element->add_control(
            'header_button_show',
            [
                'label'     => esc_html__( 'Button Show', 'labaid'),
                'type'      => Controls_Manager::SELECT,
                'default'   => '',
                'options'   => [
                    '' => esc_html__( 'Theme Setting', 'labaid'),
                    0       => esc_html__( 'Hide', 'labaid'),
                    1       => esc_html__( 'Show', 'labaid'),                    
                ],
                'condition' => [ 'style_header' => ['header-02'] ],
            ]
        );

        $element->add_control(
            'header_button_text',
            [
                'label' => esc_html__( 'Button Text', 'labaid' ),
                'type'    => Controls_Manager::TEXT,
                'default' => esc_html__( 'GET A QUOTE', 'labaid' ),
                'placeholder' => esc_html__( 'GET A QUOTE', 'labaid' ),
                'label_block' => true,
                'condition' => [ 'style_header' => ['header-01'] ],
            ]
        );

        $element->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'header_button_border',
                'label' => esc_html__( 'Border', 'labaid' ),
                'selector' => '{{WRAPPER}} .wrap-btn-header .btn-header',
            ]
        );

        $element->add_control(
            'header_button_radius',
            [
                'label' => esc_html__( 'Button Border Radius', 'labaid' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
		                'size_units' => [ 'px', '%', 'em' ],
		                'selectors' => [
		                    '{{WRAPPER}} .wrap-btn-header .btn-header' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
		                ],
            ]
        );

        $element->add_control(
            'top_header_button_color',
            [
                'label' => esc_html__( 'Button Color', 'labaid' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}}  .wrap-btn-header .btn-header' => 'color: {{VALUE}};',                  
                ],
            ]
        );

        $element->add_control(
            'top_header_button_color_hover',
            [
                'label' => esc_html__( 'Button Color Hover', 'labaid' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}}  .wrap-btn-header .btn-header:hover' => 'color: {{VALUE}};',                  
                ],
            ]
        );

        $element->add_control(
            'top_header_button_bg_color',
            [
                'label' => esc_html__( 'Button Background', 'labaid' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}}  .wrap-btn-header .btn-header' => 'background-color: {{VALUE}};',                  
                ],
            ]
        );

        $element->add_control(
            'top_header_button_bg_color_hover',
            [
                'label' => esc_html__( 'Button Background Hover', 'labaid' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}}  .wrap-btn-header .btn-header:hover:after, {{WRAPPER}}  .wrap-btn-header .btn-header:hover:before' => 'background-color: {{VALUE}};',                  
                ],
            ]
        );

        $element->add_responsive_control(
            'top_header_button_padding',
            [
                'label' => esc_html__( 'Padding', 'labaid' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .wrap-btn-header .btn-header' => 'padding: {{TOP}}{{UNIT}};',
                ],
            ]
        );


        $element->add_control(
            'h_inner_header',
            [
                'label' => esc_html__( 'Inner Header', 'labaid' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $element->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'header_inner_border',
                'label' => esc_html__( 'Border', 'labaid' ),
                'selector' => '{{WRAPPER}} #header .inner-header-menu',
            ]
        );

        $element->add_responsive_control(
            'header_inner_bg',
            [
                'label' => esc_html__( 'Header Background', 'labaid' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} #header .inner-header-menu' => 'background-color: {{VALUE}};',                  
                ],
            ]
        );

        $element->add_responsive_control(
            'header_inner_bg_sticky',
            [
                'label' => esc_html__( 'Header Background Sticky', 'labaid' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} #header.header-sticky.header-01 .inner-header' => 'background-color: {{VALUE}};',                  
                ],
                'default' => '#142441',
                'condition' => [ 
                    'style_header' => ['header-01'] 
                ],
            ]
        );

        $element->add_control(
            'header_inner_link_color',
            [
                'label' => esc_html__( 'Menu Color', 'labaid' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} #header .inner-header-menu #mainnav > ul > li > a, {{WRAPPER}} #header .inner-header-menu #mainnav ul.sub-menu > li > a' => 'color: {{VALUE}};',                  
                ],
            ]
        );
        $element->add_control(
            'header_inner_link',
            [
                'label' => esc_html__( 'Menu Color Hover & active', 'labaid' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} #header .inner-header-menu #mainnav > ul > li > a:hover, {{WRAPPER}} #header .inner-header-menu #mainnav > ul > li.current-menu-parent > a, {{WRAPPER}} #header .inner-header-menu #mainnav ul.sub-menu > li.current-menu-item > a, {{WRAPPER}} #header .inner-header-menu #mainnav ul.sub-menu > li > a:hover' => 'color: {{VALUE}};',                  
                ],
            ]
        );
        $element->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'header_inner_link_typo',
                'label' => esc_html__( 'Typography', 'labaid' ),
                'selector' => '{{WRAPPER}} #header .inner-header-menu #mainnav > ul > li > a, {{WRAPPER}} #header .inner-header-menu #mainnav ul.sub-menu > li > a',
            ]
        );

        $element->add_control(
            'h_inner_header_social',
            [
                'label' => esc_html__( 'Social', 'labaid' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $element->add_control(
            'header_inner_social_color',
            [
                'label' => esc_html__( 'Social Color', 'labaid' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .header-menu .themesflat-socials li a' => 'color: {{VALUE}};',                  
                ],
            ]
        );

        $element->add_control(
            'header_inner_social_color_hover',
            [
                'label' => esc_html__( 'Social Color Hover', 'labaid' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .header-menu .themesflat-socials li a:hover' => 'color: {{VALUE}};',                  
                ],
            ]
        );

        $element->add_responsive_control(
            'header_inner_social_margin',
            [
                'label' => esc_html__( 'Margin', 'labaid' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .header-menu .themesflat-socials' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $element->add_responsive_control(
            'header_inner_social_padding',
            [
                'label' => esc_html__( 'Padding', 'labaid' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .header-menu .themesflat-socials' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $element->add_control(
            'h_inner_header_cart_user',
            [
                'label' => esc_html__( 'Cart & User', 'labaid' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $element->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'inner_header_cart_user_typo',
                'label' => esc_html__( 'Typography', 'labaid' ),
                'selector' => '{{WRAPPER}} #header .header-wrap .header-ct-right .sign-in, {{WRAPPER}} .header-cart-wrapper span ',
            ]
        );

        $element->add_control(
            'header_cart_user_typo_color',
            [
                'label' => esc_html__( 'Color', 'labaid' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} #header .header-wrap .header-ct-right .sign-in, {{WRAPPER}} .header-cart-wrapper span' => 'color: {{VALUE}};',                  
                ],
            ]
        );

        $element->add_control(
            'header_cart_user_typo_icon_color',
            [
                'label' => esc_html__( 'Icon Color', 'labaid' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} #header .header-wrap .header-ct-right .group-sign svg path, {{WRAPPER}} .header-cart-wrapper .nav-cart-trigger svg path' => 'fill: {{VALUE}};',                  
                ],
            ]
        );

        $element->add_control(
            'h_inner_header_infor',
            [
                'label' => esc_html__( 'Information', 'labaid' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $element->add_control(
            'header_inner_infor_bg_color',
            [
                'label' => esc_html__( 'Infor Background Color', 'labaid' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .header-menu .content-phone' => 'background-color: {{VALUE}};',                  
                ],
            ]
        );

        $element->add_control(
            'header_inner_infor_color',
            [
                'label' => esc_html__( 'Infor Color', 'labaid' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .header-menu .content-phone a, {{WRAPPER}} .header-menu .content-phone span' => 'color: {{VALUE}};',                  
                ],
            ]
        );

        $element->add_control(
            'header_inner_infor_color_hover',
            [
                'label' => esc_html__( 'Infor Color Hover', 'labaid' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .header-menu .content-phone a:hover' => 'color: {{VALUE}};',                  
                ],
            ]
        );

        $element->add_responsive_control(
            'header_inner_infor_padding',
            [
                'label' => esc_html__( 'Padding', 'labaid' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .header-menu .content-phone' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $element->add_responsive_control(
            'header_inner_infor_margin',
            [
                'label' => esc_html__( 'margin', 'labaid' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .header-menu .content-phone' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );


        //Extra Classes Header
        $element->add_control(
            'extra_classes_header',
            [
                'label'   => esc_html__( 'Extra Classes', 'labaid' ),
                'type'    => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );

        $element->end_controls_section();
    }

    public function themesflat_options_page_pagetitle($element) {
        // TF Page Title
        $element->start_controls_section(
            'themesflat_pagetitle_options',
            [
                'label' => esc_html__('TF Page Title', 'labaid'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );       

        $element->add_control(
            'hide_pagetitle',
            [
                'label'     => esc_html__( 'Hide Page Title', 'labaid'),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'block',
                'options'   => [
                    'none'       => esc_html__( 'Yes', 'labaid'),
                    'block'      => esc_html__( 'No', 'labaid'),
                ],
                'selectors'  => [
                    '{{WRAPPER}} .page-title' => 'display: {{VALUE}};',
                ],
            ]
        ); 

        $element->add_responsive_control(
            'pagetitle_padding',
            [
                'label' => esc_html__( 'Padding', 'labaid' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'allowed_dimensions' => [ 'top', 'bottom' ],
                'selectors' => [
                    '{{WRAPPER}} .page-title' => 'padding-top: {{TOP}}{{UNIT}}; padding-bottom: {{BOTTOM}}{{UNIT}};',
                ],
                'condition' => [ 'hide_pagetitle' => 'block' ]
            ]
        ); 

        $element->add_responsive_control(
            'pagetitle_margin',
            [
                'label' => esc_html__( 'Margin', 'labaid' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'allowed_dimensions' => [ 'top', 'bottom' ],
                'selectors' => [
                    '{{WRAPPER}} .page-title' => 'margin-top: {{TOP}}{{UNIT}}; margin-bottom: {{BOTTOM}}{{UNIT}};',
                ],
                'condition' => [ 'hide_pagetitle' => 'block' ]
            ]
        );              

        $element->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'pagetitle_bg',
                'label' => esc_html__( 'Background', 'labaid' ),
                'types' => [ 'classic', 'gradient', 'video' ],
                'selector' => '{{WRAPPER}} .page-title',
                'condition' => [ 'hide_pagetitle' => 'block' ]
            ]
        );

        $element->add_control(
            'pagetitle_overlay_color',
            [
                'label' => esc_html__( 'Overlay Color', 'labaid' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .page-title .overlay' => 'background: {{VALUE}}; opacity: 100%;filter: alpha(opacity=100);',
                ],
                'condition' => [ 'hide_pagetitle' => 'block' ]
            ]
        );

        //Extra Classes Page Title
        $element->add_control(
            'extra_classes_pagetitle',
            [
                'label'   => esc_html__( 'Extra Classes', 'labaid' ),
                'type'    => Controls_Manager::TEXT,
                'label_block' => true,
                'separator' => 'before'
            ]
        );

        $element->end_controls_section();
    }

    public function themesflat_options_page_footer($element) {
        // TF Footer
        $element->start_controls_section(
            'themesflat_footer_options',
            [
                'label' => esc_html__('TF Footer', 'labaid'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );

        $element->add_control(
            'footer_heading',
            [
                'label'     => esc_html__( 'Footer', 'labaid'),
                'type'      => Controls_Manager::HEADING,
            ]
        );       

        $element->add_control(
            'hide_footer',
            [
                'label'     => esc_html__( 'Hide Footer', 'labaid'),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'block',
                'options'   => [
                    'none'       => esc_html__( 'Yes', 'labaid'),
                    'block'      => esc_html__( 'No', 'labaid'),
                ],
                'selectors'  => [
                    '{{WRAPPER}} #footer' => 'display: {{VALUE}};',
                    '{{WRAPPER}} .info-footer' => 'display: {{VALUE}};' 
                ],
            ]
        );

        $element->add_responsive_control(
            'footer_padding',
            [
                'label' => esc_html__( 'Padding', 'labaid' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'allowed_dimensions' => [ 'top', 'bottom' ],
                'selectors' => [
                    '{{WRAPPER}} #footer' => 'padding-top: {{TOP}}{{UNIT}}; padding-bottom: {{BOTTOM}}{{UNIT}};',
                ],
                'condition' => [ 'hide_footer' => 'block' ]
            ]
        );

        $element->add_control(
            'show_partner',
            [
                'label'     => esc_html__( 'Partner', 'labaid'),
                'type'      => Controls_Manager::SELECT,
                'default'   => '',
                'options'   => [
                    '' => esc_html__( 'Theme Setting', 'labaid'),
                    1 => esc_html__( 'Show', 'labaid' ),
                    0 => esc_html__( 'Hide', 'labaid' ),
                ],
                'condition' => [ 'hide_footer' => 'block' ]
            ]
        ); 

        $element->add_control(
            'show_action_box',
            [
                'label'     => esc_html__( 'Action Box', 'labaid'),
                'type'      => Controls_Manager::SELECT,
                'default'   => '',
                'options'   => [
                    '' => esc_html__( 'Theme Setting', 'labaid'),
                    1 => esc_html__( 'Show', 'labaid' ),
                    0 => esc_html__( 'Hide', 'labaid' ),
                ],
                'condition' => [ 'hide_footer' => 'block' ]
            ]
        ); 

        $element->add_responsive_control(
            'show_action_box_padding',
            [
                'label' => esc_html__( 'Padding', 'labaid' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'allowed_dimensions' => [ 'top', 'bottom' ],
                'selectors' => [
                    '{{WRAPPER}} .themesflat-action-box' => 'padding-top: {{TOP}}{{UNIT}}; padding-bottom: {{BOTTOM}}{{UNIT}};',
                ],
                'condition' => [ 'hide_footer' => 'block' ]
            ]
        ); 

        $element->add_control(
            'show_action_box_color',
            [
                'label' => esc_html__( 'Action Text Color', 'labaid' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .themesflat-action-box .heading-wrap p, {{WRAPPER}} .themesflat-action-box .heading-wrap .heading' => 'color: {{VALUE}};',                  
                ],
                'condition' => [ 'hide_footer' => 'block' ]
            ]
        );

        $element->add_control(
            'show_action_box_color_bg',
            [
                'label' => esc_html__( 'Action Background Color', 'labaid' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .themesflat-action-box .overlay' => 'background-color: {{VALUE}};',                  
                ],
                'condition' => [ 'hide_footer' => 'block' ]
            ]
        );

        $element->add_control(
            'footer_color',
            [
                'label' => esc_html__( 'Color', 'labaid' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} #footer' => 'color: {{VALUE}}',
                    '{{WRAPPER}} #footer h1, {{WRAPPER}} #footer h2, {{WRAPPER}} #footer h3, {{WRAPPER}} #footer h4, {{WRAPPER}} #footer h5, {{WRAPPER}} #footer h6' => 'color: {{VALUE}}',
                    '{{WRAPPER}} #footer, #footer input, #footer select, {{WRAPPER}} #footer textarea, {{WRAPPER}} #footer a, {{WRAPPER}} footer .widget.widget-recent-news li .text .post-date, {{WRAPPER}} footer .widget.widget_latest_news li .text .post-date, {{WRAPPER}} #footer .footer-widgets .widget.widget_themesflat_socials ul li a' => 'color: {{VALUE}}',
                ],
                'condition' => [ 'hide_footer' => 'block' ]
            ]
        );       

        $element->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'footer_bg',
                'label' => esc_html__( 'Background', 'labaid' ),
                'types' => [ 'classic', 'gradient', 'video' ],
                'selector' => '{{WRAPPER}} .footer_background .overlay-footer',
                'condition' => [ 'hide_footer' => 'block' ]
            ]
        );

        $element->add_control(
            'footer_bg_overlay',
            [
                'label' => esc_html__( 'Background Overlay', 'labaid' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .footer_background' => 'background-color: {{VALUE}}',
                ],
                'condition' => [ 'hide_footer' => 'block' ]
            ]
        );

        // Bottom
        $element->add_control(
            'bottom_heading',
            [
                'label'     => esc_html__( 'Bottom', 'labaid'),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );

        $element->add_control(
            'hide_bottom',
            [
                'label'     => esc_html__( 'Hide?', 'labaid'),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'block',
                'options'   => [
                    'none'       => esc_html__( 'Yes', 'labaid'),
                    'block'      => esc_html__( 'No', 'labaid'),
                ],
                'selectors'  => [
                    '{{WRAPPER}} #bottom' => 'display: {{VALUE}};' 
                ],
            ]
        );

        $element->add_control(
            'bottom_color',
            [
                'label' => esc_html__( 'Color', 'labaid' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .bottom *' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .bottom, {{WRAPPER}} .bottom a' => 'color: {{VALUE}}',
                ],
                'condition' => [ 'hide_bottom' => 'block' ]
            ]
        );

        $element->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'bottom_bg',
                'label' => esc_html__( 'Background', 'labaid' ),
                'types' => [ 'classic', 'gradient', 'video' ],
                'selector' => '{{WRAPPER}} #bottom',
                'condition' => [ 'hide_bottom' => 'block']
            ]
        );

        $element->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'bottom_border',
                'label' => esc_html__( 'Border', 'labaid' ),
                'selector' => '{{WRAPPER}} #bottom .container-inside',
                'condition' => [ 'hide_bottom' => 'block']
            ]
        );

        $element->add_responsive_control(
            'bottom_padding',
            [
                'label' => esc_html__( 'Padding', 'labaid' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'allowed_dimensions' => [ 'top', 'bottom' ],
                'selectors' => [
                    '{{WRAPPER}} #bottom .container-inside' => 'padding-top: {{TOP}}{{UNIT}}; padding-bottom: {{BOTTOM}}{{UNIT}};',
                ],
                'condition' => [ 'hide_bottom' => 'block']
            ]
        );

        //Extra Classes Footer
        $element->add_control(
            'extra_classes_footer',
            [
                'label'   => esc_html__( 'Extra Classes', 'labaid' ),
                'type'    => Controls_Manager::TEXT,
                'label_block' => true,
                'separator' => 'before'
            ]
        );

        $element->end_controls_section();
    }

    public function themesflat_options_page($element) {
        // TF Page
        $element->start_controls_section(
            'themesflat_page_options',
            [
                'label' => esc_html__('TF Page', 'labaid'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );

        $element->add_control(
            'page_sidebar_layout',
            [
                'label'     => esc_html__( 'Sidebar Position', 'labaid'),
                'type'      => Controls_Manager::SELECT,
                'default'   => '',
                'options'   => [
                    '' => esc_html__( 'No Sidebar', 'labaid'),
                    'sidebar-right'     => esc_html__( 'Sidebar Right','labaid' ),
                    'sidebar-left'      =>  esc_html__( 'Sidebar Left','labaid' ),
                    'fullwidth'         =>   esc_html__( 'Full Width','labaid' ),
                    'fullwidth-small'   =>   esc_html__( 'Full Width Small','labaid' ),
                    'fullwidth-center'  =>   esc_html__( 'Full Width Center','labaid' ),
                ],
            ]
        );

        $element->add_control(
            'main_content_heading',
            [
                'label'     => esc_html__( 'Main Content', 'labaid'),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );

        $element->add_responsive_control(
            'main_content_padding',
            [
                'label' => esc_html__( 'Padding', 'labaid' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'allowed_dimensions' => [ 'top', 'bottom' ],
                'selectors' => [
                    '{{WRAPPER}} #themesflat-content' => 'padding-top: {{TOP}}{{UNIT}}; padding-bottom: {{BOTTOM}}{{UNIT}};',
                ],
            ]
        ); 

        $element->add_responsive_control(
            'main_content_margin',
            [
                'label' => esc_html__( 'Margin', 'labaid' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'allowed_dimensions' => [ 'top', 'bottom' ],
                'selectors' => [
                    '{{WRAPPER}} #themesflat-content' => 'margin-top: {{TOP}}{{UNIT}}; margin-bottom: {{BOTTOM}}{{UNIT}};',
                ],
            ]
        );

        $element->end_controls_section();
    }

    public function themesflat_options_services($element) {
        // TF Services
        $element->start_controls_section(
            'themesflat_services_options',
            [
                'label' => esc_html__('TF Services', 'labaid'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );

        $element->add_control(
            'services_post_heading',
            [
                'label'     => esc_html__( 'Services Post', 'labaid'),
                'type'      => Controls_Manager::HEADING,
            ]
        );

        $element->add_control(
            'services_post_icon',
            [
                'label' => esc_html__( 'Post Icon', 'labaid' ),
                'type' => \Elementor\Controls_Manager::ICONS,
            ]
        );


        $element->end_controls_section();
    }

    public function themesflat_options_team($element) {
        // TF team
        $element->start_controls_section(
            'themesflat_team_options',
            [
                'label' => esc_html__('TF Team', 'labaid'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );

        $element->add_control(
            'team_post_heading',
            [
                'label'     => esc_html__( 'Team Post Content', 'labaid'),
                'type'      => Controls_Manager::HEADING,
            ]
        );

        $element->add_control(
            'team_post_position',
            [
                'label' => esc_html__( 'Position Member', 'labaid' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__( 'top researcher', 'labaid' ),
                'placeholder' => esc_html__( 'top researcher', 'labaid' ),
                'label_block' => true,
            ]
        );

        $element->add_control(
            'team_post_subtitle',
            [
                'label' => esc_html__( 'Subtitle', 'labaid' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__( 'Netherland Medical College', 'labaid' ),
                'placeholder' => esc_html__( 'Subtitle', 'labaid' ),
                'label_block' => true,
            ]
        );

        $element->add_control(
            'team_post_title',
            [
                'label' => esc_html__( 'Title', 'labaid' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__( 'About Me: ', 'labaid' ),
                'placeholder' => esc_html__( 'Title', 'labaid' ),
                'label_block' => true,
            ]
        );

        $element->add_control(
            'team_post_description',
            [
                'label' => esc_html__( 'Description', 'labaid' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__( 'Nunc fringilla est nec lobortis dictum. Fusce a dolor risus. Ut suscipit arcu sed turpis rhoncus dapibus. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Aenean fringilla nunc diam, ac elementu justo pellentesque in. Sed elementum elem quam at elementum. Vestibulum et mollis metus. Fusce porttitor laoreet urna, eget luctus puru rhoncus non. Sed faucibus purus at tincidunt tristique.', 'labaid' ),
                'placeholder' => esc_html__( 'description', 'labaid' ),
                'label_block' => true,
            ]
        );


        $element->add_control(
            'team_post_social_heading',
            [
                'label'     => esc_html__( 'Team Post Social', 'labaid'),
                'type'      => Controls_Manager::HEADING,
            ]
        );

        $element->add_control(
            'team_post_social_icon_1',
            [
                'label' => esc_html__( 'Icon 1', 'labaid' ),
                'type' => Controls_Manager::ICONS,
                'default' => [
                    'value' => 'icon-labaid-la-41',
                    'library' => 'theme_icon',
                ],
            ]
        );
        $element->add_control(
            'team_post_social_link_1',
            [
                'label' => esc_html__( 'Link 1', 'labaid' ),
                'type' => Controls_Manager::URL,
                'default' => [
                    'url' => '#',
                    'is_external' => true,
                    'nofollow' => true,
                    'custom_attributes' => '',
                ],
                'placeholder' => esc_html__( 'https://your-link.com', 'labaid' ),
                'conditions' => [
                    'relation' => 'or',
                    'terms' => [
                        [
                            'name' => 'team_post_social_icon_1[value]',
                            'operator' => '!=',
                            'value' => '',
                        ],
                    ],
                ],
            ]
        );

        $element->add_control(
            'team_post_social_icon_2',
            [
                'label' => esc_html__( 'Icon 2', 'labaid' ),
                'type' => Controls_Manager::ICONS,
                'default' => [
                    'value' => 'icon-labaid-la-40',
                    'library' => 'theme_icon',
                ],
            ]
        );
        $element->add_control(
            'team_post_social_link_2',
            [
                'label' => esc_html__( 'Link 2', 'labaid' ),
                'type' => Controls_Manager::URL,
                'default' => [
                    'url' => '#',
                    'is_external' => true,
                    'nofollow' => true,
                    'custom_attributes' => '',
                ],
                'placeholder' => esc_html__( 'https://your-link.com', 'labaid' ),
                'conditions' => [
                    'relation' => 'or',
                    'terms' => [
                        [
                            'name' => 'team_post_social_icon_2[value]',
                            'operator' => '!=',
                            'value' => '',
                        ],
                    ],
                ],
            ]
        );

        $element->add_control(
            'team_post_social_icon_3',
            [
                'label' => esc_html__( 'Icon 3', 'labaid' ),
                'type' => Controls_Manager::ICONS,
                'default' => [
                    'value' => 'icon-labaid-dribble',
                    'library' => 'theme_icon',
                ],
            ]
        );
        $element->add_control(
            'team_post_social_link_3',
            [
                'label' => esc_html__( 'Link 3', 'labaid' ),
                'type' => Controls_Manager::URL,
                'default' => [
                    'url' => '#',
                    'is_external' => true,
                    'nofollow' => true,
                    'custom_attributes' => '',
                ],
                'placeholder' => esc_html__( 'https://your-link.com', 'labaid' ),
                'conditions' => [
                    'relation' => 'or',
                    'terms' => [
                        [
                            'name' => 'team_post_social_icon_3[value]',
                            'operator' => '!=',
                            'value' => '',
                        ],
                    ],
                ],
            ]
        );

        $element->add_control(
            'team_post_social_icon_4',
            [
                'label' => esc_html__( 'Icon 4', 'labaid' ),
                'type' => Controls_Manager::ICONS,
                ]
        );
        $element->add_control(
            'team_post_social_link_4',
            [
                'label' => esc_html__( 'Link 4', 'labaid' ),
                'type' => Controls_Manager::URL,
                'default' => [
                    'url' => '#',
                    'is_external' => true,
                    'nofollow' => true,
                    'custom_attributes' => '',
                ],
                'placeholder' => esc_html__( 'https://your-link.com', 'labaid' ),
                'conditions' => [
                    'relation' => 'or',
                    'terms' => [
                        [
                            'name' => 'team_post_social_icon_4[value]',
                            'operator' => '!=',
                            'value' => '',
                        ],
                    ],
                ],
            ]
        );

        $element->add_control(
            'team_post_button',
            [
                'label'     => esc_html__( 'Team Post Button', 'labaid'),
                'type'      => Controls_Manager::HEADING,
            ]
        );

        $element->add_control(
            'team_post_button_text',
            [
                'label' => esc_html__( 'Text Button', 'labaid' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__( 'Emergency Cases', 'labaid' ),
                'placeholder' => esc_html__( 'Read More', 'labaid' ),
                'label_block' => true,
            ]
        );

        $element->add_control(
            'team_post_button_url',
            [
                'label' => esc_html__( 'Link Button', 'labaid' ),
                'type' => Controls_Manager::URL,
                'default' => [
                    'url' => '#',
                    'is_external' => true,
                    'nofollow' => true,
                    'custom_attributes' => '',
                ],
                'placeholder' => esc_html__( 'https://your-link.com', 'labaid' ),
            ]
        );

        $element->add_control(
            'team_post_button_icon',
            [
                'label' => esc_html__( 'Icon', 'labaid' ),
                'type' => Controls_Manager::ICONS,
                'default' => [
                    'value' => 'icon-labaid-la-26',
                    'library' => 'theme_icon',
                ],
            ]
        );

        $element->end_controls_section();
    }

    public function themesflat_options_portfolio($element) {
        // TF Portfolio
        $element->start_controls_section(
            'themesflat_portfolio_options',
            [
                'label' => esc_html__('TF Portfolio', 'labaid'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );

        $element->add_control(
            'portfolio_post_img',
            [
                'label'   => esc_html__( 'Image Detail', 'labaid' ),
                'type'    => Controls_Manager::MEDIA,
            ]
        );

        $element->add_control(
            'portfolio_post_heading',
            [
                'label'     => esc_html__( 'Portfolio Post Meta', 'labaid'),
                'type'      => Controls_Manager::HEADING,
            ]
        );

        

        $element->add_control(
            'portfolio_post_clients',
            [
                'label' => esc_html__( 'Clients', 'labaid' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__( 'Themesflat', 'labaid' ),
                'placeholder' => esc_html__( 'Themesflat', 'labaid' ),
                'label_block' => true,
            ]
        );
        $element->add_control(
            'portfolio_post_location',
            [
                'label' => esc_html__( 'Website', 'labaid' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__( 'themesflat.com', 'labaid' ),
                'placeholder' => esc_html__( 'themesflat.com', 'labaid' ),
                'label_block' => true,
            ]
        );
        $element->add_control(
            'portfolio_post_icon_date',
            [
                'label' => esc_html__( 'Icon Date', 'labaid' ),
                'type' => Controls_Manager::ICONS,
                'default' => [
                    'value' => 'icon-labaid-calendar',
                    'library' => 'theme_icon',
                ],
            ]
        );
        $element->add_control(
            'portfolio_post_icon_category',
            [
                'label' => esc_html__( 'Icon Category', 'labaid' ),
                'type' => Controls_Manager::ICONS,
                'default' => [
                    'value' => 'icon-labaid-tag',
                    'library' => 'theme_icon',
                ],
            ]
        );
        $element->add_control(
            'portfolio_post_icon_client',
            [
                'label' => esc_html__( 'Icon Client', 'labaid' ),
                'type' => Controls_Manager::ICONS,
                'default' => [
                    'value' => 'icon-labaid-user',
                    'library' => 'theme_icon',
                ],
            ]
        );
        $element->add_control(
            'portfolio_post_icon_website',
            [
                'label' => esc_html__( 'Icon Website', 'labaid' ),
                'type' => Controls_Manager::ICONS,
                'default' => [
                    'value' => 'icon-labaid-web',
                    'library' => 'theme_icon',
                ],
            ]
        );

         $element->add_control(
            'portfolio_post_social_heading',
            [
                'label'     => esc_html__( 'portfolio Post Social', 'labaid'),
                'type'      => Controls_Manager::HEADING,
            ]
        );

        $element->add_control(
            'portfolio_post_social_icon_1',
            [
                'label' => esc_html__( 'Icon 1', 'labaid' ),
                'type' => Controls_Manager::ICONS,
                'default' => [
                    'value' => 'icon-labaid-facebook',
                    'library' => 'theme_icon',
                ],
            ]
        );
        $element->add_control(
            'portfolio_post_social_link_1',
            [
                'label' => esc_html__( 'Link 1', 'labaid' ),
                'type' => Controls_Manager::URL,
                'default' => [
                    'url' => '#',
                    'is_external' => true,
                    'nofollow' => true,
                    'custom_attributes' => '',
                ],
                'placeholder' => esc_html__( 'https://your-link.com', 'labaid' ),
                'conditions' => [
                    'relation' => 'or',
                    'terms' => [
                        [
                            'name' => 'portfolio_post_social_icon_1[value]',
                            'operator' => '!=',
                            'value' => '',
                        ],
                    ],
                ],
            ]
        );

        $element->add_control(
            'portfolio_post_social_icon_2',
            [
                'label' => esc_html__( 'Icon 2', 'labaid' ),
                'type' => Controls_Manager::ICONS,
                'default' => [
                    'value' => 'icon-labaid-twitter',
                    'library' => 'theme_icon',
                ],
            ]
        );
        $element->add_control(
            'portfolio_post_social_link_2',
            [
                'label' => esc_html__( 'Link 2', 'labaid' ),
                'type' => Controls_Manager::URL,
                'default' => [
                    'url' => '#',
                    'is_external' => true,
                    'nofollow' => true,
                    'custom_attributes' => '',
                ],
                'placeholder' => esc_html__( 'https://your-link.com', 'labaid' ),
                'conditions' => [
                    'relation' => 'or',
                    'terms' => [
                        [
                            'name' => 'portfolio_post_social_icon_2[value]',
                            'operator' => '!=',
                            'value' => '',
                        ],
                    ],
                ],
            ]
        );

        $element->add_control(
            'portfolio_post_social_icon_3',
            [
                'label' => esc_html__( 'Icon 3', 'labaid' ),
                'type' => Controls_Manager::ICONS,
                'default' => [
                    'value' => 'icon-labaid-linkedin',
                    'library' => 'theme_icon',
                ],
            ]
        );
        $element->add_control(
            'portfolio_post_social_link_3',
            [
                'label' => esc_html__( 'Link 3', 'labaid' ),
                'type' => Controls_Manager::URL,
                'default' => [
                    'url' => '#',
                    'is_external' => true,
                    'nofollow' => true,
                    'custom_attributes' => '',
                ],
                'placeholder' => esc_html__( 'https://your-link.com', 'labaid' ),
                'conditions' => [
                    'relation' => 'or',
                    'terms' => [
                        [
                            'name' => 'portfolio_post_social_icon_3[value]',
                            'operator' => '!=',
                            'value' => '',
                        ],
                    ],
                ],
            ]
        );

        $element->add_control(
            'portfolio_post_social_icon_4',
            [
                'label' => esc_html__( 'Icon 4', 'labaid' ),
                'type' => Controls_Manager::ICONS,
                'default' => [
                    'value' => 'icon-labaid-instagram',
                    'library' => 'theme_icon',
                ],
            ]
        );
        $element->add_control(
            'portfolio_post_social_link_4',
            [
                'label' => esc_html__( 'Link 4', 'labaid' ),
                'type' => Controls_Manager::URL,
                'default' => [
                    'url' => '#',
                    'is_external' => true,
                    'nofollow' => true,
                    'custom_attributes' => '',
                ],
                'placeholder' => esc_html__( 'https://your-link.com', 'labaid' ),
                'conditions' => [
                    'relation' => 'or',
                    'terms' => [
                        [
                            'name' => 'portfolio_post_social_icon_4[value]',
                            'operator' => '!=',
                            'value' => '',
                        ],
                    ],
                ],
            ]
        );
        $element->end_controls_section();
    }
}

new themesflat_options_elementor();